# serotiny

`serotiny` is a collection of deep learning related tools and primitives, loosely meant
to be used in projects started from [lightning-hydra-template](https://github.com/ashleve/lightning-hydra-template)

For more information, check our [documentation](https://allencell.github.io/serotiny).

## Authors

- Guilherme Pires @colobas
- Ryan Spangler @prismofeverything
- Ritvik Vasan @ritvikvasan
- Caleb Chan @calebium
- Theo Knijnenburg @tknijnen
- Nick Gomez @gomeznick86

## Citing

If you find serotiny useful, please cite this repository as:

```
Serotiny Authors (2022). Serotiny: a framework of tools to structure, configure and drive deep learning projects [Computer software]. GitHub. https://github.com/AllenCellModeling/serotiny
Free software: BSD-3-Clause
```
